bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 24. Aventiure
___________________________________________________ #### Aventv wie die boten ze Rine quamen vn– wie si #### danne schieden
| ### <Die> boten dannen fvren vber Hvnin lant ### zvo den Burgonden dar waren si gesant ### nach drin edeln kunigen vn– ovch nach ir man ### die solden chomen Ezelen des man gahen do began ### Hin ze Bechelaren chomen si geriten ### da diente man in gerne daz wart niht vermiten ### sin dienst enbot do Rvdeger vn– ovch Gotelint ### bi in hin ze Rine vn– ovch des marcgraven kint
###### 1453 | ### Sine liezens ane gabe von in niht schei[56r]den dan ### daz deste baz gefveren die Ezelen man ### Vten vn– ir kinden enbot do Rvedeger ### sine heten in so wæge deheinen marcgraven mer
###### 1454 | ### Si enbvten ovch Prvnh' dienste vn– gvot ### triwe un– minne vn– willigen mvot ### do si die rede gehorte die boten mvsin varn ### si bat div marcgrauinne got von himele bewarn
| ### E daz di boten chomen vol dvrch Bayerlant ### Wærbel der vil snelle den gvten bisschof vant ### waz der do sinen frivnden hin ze Rine enbot ### daz ist mir vngewizzen niwan sin golt also rot
###### 1456 | ### daz gab er in ze minne ritern er si lie ### do sprach der bisschof Pilgerim solde ich si sehen hie ### mir wære wol ze mvote die swester svne min ### ich mach leider selten zvo zin chomen an den Rin
###### 1457 | ### Welhe wege si fvoren ze Rine dvrch div lant ### desen chan ich niht bescheiden ir golt vn– ir gewant ### daz ennam in niemen man vorht ir herren haz ### Ezel was vil gewaltich man erchande in allen landen daz
###### 1458 | ### Inre tagen zehenen si chomen an den Rin ### ze Wormze zv der veste Wærbel vn– Swæmmelin ### do sagte man div mære den kvnigen vn– ir man ### da choemen boten vremde Gunther vragen do began
| ### Do sprach der vogt von Rine wer tvot vns bechant ### von disen vremden rechen die choment in daz lant ### daz enwesse nieman vnze si gesach ### Hagene der chvene der helt zvo Gunthere sprach
###### 1460 | ### Uns choment niwe mære des wil ich iv veriehn ### die Ezeln videlære die han ich hie gesehn ### si hat iwer swester gesendet an den Rin ### durch die Ezelen liebe si svln vns willechomen sin
###### 1461 | ### Si riten vil bereite fver den palas dan ### ez gefvren herrenlicher nie fvrsten spileman ### des chuniges ingesinde enpfie si sa zehant ### ir rôs man herbergen vn– hiez behalten ir gewant
| ### Ir reisechleider waren rich vn– so getan ### daz si mit eren mohten fvr den kunic gan ### der enwolden si niht mere da ze hove tragn ### obs iemen nemen wolde die boten hiezen daz sagn
###### 1463 | ### In der selben maze man ovch lvte vant ### die ez vil gerne namen den wart ez gesant ### do leiten an die geste verre richer wat ### als ez boten kuniges ze tragen herlichen stat
###### 1464 | ### Do gie mit vrlovbe da der kunic saz ### daz Ezelen gesinde vil gerne sah man daz ### Hagene von den sedele gein den boten spranch ### vn– lief in engegene des sagten im die chnappen danch
###### 1465 | ### Durch div chvnden mære vragen er began ### wie sich gehabte Ezele vn– ovch sine man ### do sprach der videlære daz lant gestvnt nie baz ### noch wrden vro die [56v]die lvote ich sagiv endechliche daz
| ### Er brahtes zv den wirte der palas der was vol ### do enpfie man die geste so man von rehte sol ### minnechliche grvezen in ander kvnige lant ### Swæmmil vil der degene da bi Gunthere vant
###### 1467 | ### Der chunic gezogenliche grvzen si began ### sit willechomen beide ir Ezelen spileman ### vn– iwer hergesellen hat ivch her gesant ### der kunic von den Hvnin zvo der Burgonden lant
###### 1468 | ### Mit zvht si nigen beide do sprach Wærbelin ### iv enbivtet sinen dienest der liebe herre min ### vn– Chriemh' iwer swester her in dizze lant ### si habent vns iv heleden in grozen triwen her gesant
###### 1469 | ### Do sprach der fvrste riche der mære bin ich vro ### wie gehabt sich Ezele so sprach der chunic do ### vn– Chriemh' min swester vzer Hvnen lant ### do sprach der videlære div mære tvn ich iv bechant
###### 1470 | ### Sich gehabten chunige ir svlt wol wizzen daz ### in deheinem lande vrolicher noch baz ### vn– allez ir gedigene die mage vn– ovch ir man ### si frevten sich der reise do wir schieden von in dan
| ### Gnade siner dienste die er mir enboten hat ### vn– ovch miner swester mir ist liep daz also stat ### daz si so lebnt mit vrevden der chunic vnt sine man ### wande ich doch der mære gevraget sorgende han
###### 1472 | ### Die zwene ivngen chvnige waren ovch nv chomen ### wande si div mære heten erst vernomen ### dvrch ir swester liebe die boten gerne sach ### Giselher der ivnge der zvo zin gvetlichen sprach
###### 1473 | ### Ir boten soldet groze vns willechomen sin ### ob ir dicker woldet zvns riten an den Rin ### ich wæn ir frivnde fvndet die ir gerne moehtet sehen ### iv solde von vns degenen lvzzil leides geschehn
###### 1474 | ### Wir getrwoen iv aller eren sprach do Swæmmelin ### ine chvnd iv niht bewæren mit den sinnen min ### wie minneklich iv Ezele her enboten hat ### vn– iwer edeliv swester der dinch in hoher wirde stat
###### 1475 | ### Gnade vn– triwe mant ivch des kuniges wip ### vn– daz ir ie was wæge iwer herce vn– iwer lip ### vn– ze vorderst dem kunige sin wir her gesant ### daz ir gervchet riten zvo zin in der Hvnin lant
###### 1476 | ### Ez sol ovch mit iv riten der herre Gernot ### Ezele der riche iv allen daz enbot ### ob ir ivch iwer swester niht sehn woldet lan ### so wolde er gerne wizzen waz er iv rechen hete getan
###### 1477 | ### daz ir also vremdet in vn– siniv lant ### ob iv div kuniginne wære nie bechant ### so moeht er doch verdienen daz in ir rvchet sehn ### swenne daz geschêhe so wær im liebe geschehn
| ### Do sprach der kunic Gvnther nv lat die rede stan ### vn– vart ze herbergen ich wil ivch hoeren lan ### in disen siben [S 91r Z 5] nachten wil ich in sein lant ### swes ich mich berate die maere tun ich ew bechant
###### 1479 | ### Do sprach der bote Waerbel chünde daz geschehen ### das wir meine frawn mochte e gesehen ### Vtten die vil reichen e wir schufen vns gemach ### Geyselher der edel do ail zuchticleich sprach
###### 1480 | ### Das ensol ew niermant wenden welt ir fur si gan ### da habt ir meiner mueter willen an getan ### wan– si sicht ew gern durch die szvester meine ### vnd durch den chünig Etzln des sult ir an zweiuel sein
###### 1481 | ### Geyselher si pracht da sein muter sas ### sy sach die boten gern– mit trewen tet si das ### si grüzt sei mit tugent wan si was wol gemuot ### ia daucht [91v]si die maere von der chüniginne guot
###### 1482 | ### Mein fraw ew here enbivtet so sprach Swaemmelin ### ir dienst in grossen trewen des sult ir sicher sein ### das ir seit ir so frömde daz haizzet si ew ### mute tragen
###### 1483 | ### Da sprach die chünigin das mag nicht laider gesein ### swie gern ich dikch saech die liebe tochter meine ### ia ist mir ze verre des edln chunigs weip ### nu sein immer <saelich> baide si vn– Ettzln leip
###### 1484 | ### Ir solt mich lazzen wissen e daz ir raumet hie ### wenne ir reiten wellet in gesach so gern nie ### boten in langen zeiten danne ich ew hhan gesehhen ### die boten ir do lobten daz si das liezzen geschehen
###### 1485 | ### Zen herbergen do fuoren die von Heunen lannt ### da het der chünig reiche nach den frivnden sein gesant ### Gunther der vil edel fragt sein man ### wie in die rede behagte vil manger raten do began
###### 1486 | ### er rite wol mit ern in chünig Ettzeln lant ### das rieten im die pesten die dar vnder vant ### newer Hagen alaine dem waz ez grimme lait ### er sprach [92r]zu dem chhünig taugen ir habt ew selben widersait
###### 1487 | ### Nu ist ew wol gewissen was wir han getan ### des müg wir immer sorge auf Chrimhilden han ### auch slug ich ze tode ir man mit meiner hant ### wie getorsten wir gereiten in des chünigs Ettzln lant
###### 1488 | ### Do sprach der chünig reiche mneine swester lie den tzorn ### mit chüsse minnicleich si hat auf vns verchorn ### daz wir ir ie getaten e daz si hinnen rait ### ez en sey et Hagen danne ew ainer von ir widerseit
###### 1489 | ### Nu lat ew nicht betrigen sprach Hagen swes si iehen ### die boten von den Heunen vnd welt ir Chrimhilden sehen ### ir mugt do wol verliesen ewer ere vn– ewrn leip ### ez ist vil lanch raeche des reichen chünig Etzeln weip
###### 1490 | ### Do sprach zu dem rate der fürste Gernot ### ob ir nu von schulden forchtet den tod ### in <heunischen> reichen solden wir ez dar durch lan ### wir <ensaehn–> vnser swester daz waer zaegleich getan
###### 1491 | ### Do sprach der herre Geyselher zu dem [92v]degen ### seit ir ew schuldig wizzet frivnt her Hagen ### so sultir hie beleiben vnd vil wol bewaren ### vnd lazzet die getürren mit vns <zu> den Heunen varen
###### 1492 | ### Do begunde zuren von Tronge der degen ### ich wil daz ir iemant füret auf den wegen ### der mit ew türre reiten hin ze houe pas ### seit ir nicht welt erwinden ich lazze ew wol versuchen das
###### 1493 | ### Do sprach der chüchen maister Ruomolt der degen ### gester vnd ewer selber mügt ir haizzen phlegen ### nach ewers selben willen zr habt vil guten rat ### vnd wizzet daz ew Hagen daz waegist noch geraten hat
###### 1494 | ### Vnd wolt ir im nicht volgen ew ratet Ruomolt ### ich pin ew mit trewen vil dienstleichn– holt ### daz ir hie beleibet durch den willen meine ### vnd lat den chünig Etzel dort pei Chrimhilden seine
###### 1495 | ### Wie chunde ew in der wolde immer pas gewesen ### ir mügt vor ewrn veinden hie haime wol genesen ### ir sult mit reicher waete ziren wol den leip ### trinchet [93r]wein den pesten vnd minnet waetleichiv weip
###### 1496 | ### Dar zu geit man ew speise die pesten die man hat ### indert in der werlde ewer lant vil schon stat ### ir mügt euch wol Etzln hochtzeit mit ern wol bewegen ### vnd mügt mit ewrn frewnden vil guter chürtzweile pflegen
###### 1497 | ### Ob ir nicht anders hiete daz ir möchte geleben ### ich wolde ew ain speizze den volln immer geben ### sieden in öl geprawen daz ist Ruomoldes rat ### so ist ez sust angistleichn– erhebn da zen <Heunen> stat
###### 1498 | ### Ich waiz daz meine frawe Grimhhilde ew nimmer wirdet holt ### auch habt ir vn– Hagen zu ir anders nicht versolt ### des sult ir beleiben ez mag ew werden leit ### ir chomet ez an aine ende daz ich ew nicht han missesait
###### 1499 | ### Des rat ich ew ### michel sanfte lösen hie die phant ### danne da zen Heunen ich wais wie ez da gestat ### ir sult beleiben herre daz ist trewen meine rat
###### 1500 | ### Wir enwellen nicht beleiben sprach do Gernot ### seit das vns meine swester so [93v]frivntlieh enbot ### vnd Etzel der reiche zweu solde wir das lan ### der dar nicht welle der mag hie heime bestan
###### 1501 | ### Entrewen sprach do Ruomolt ich sols der aine sein ### der durch Etzel hochtzeit chuompt nimmer vber den Rein ### <zweu> sold ich daz wagen daz ich waegers han ### die weil ich mag immer ich wil mich selben leben lan
###### 1502 | ### Des selben wil ich volgen sprach Ortwin der degen ### ich wil des geschhaftes hie haime mit ew phlegen ### do sprach ir genuog si woldens auch bewaren ### got lazz ew liebn– herrn zen Heunen wol bewaren
###### 1503 | ### Der chünig begunde züren do er daz gesach ### daz die hie haime wolden schaffen ir gemachh ### darvmb wir ez nicht lazzen [57r] wir mvzen an die vart ### ez waldet gvter sinne der sich alle zite bewart
| ### Nv lat ivch vnbilden sprach do Hagene niht ### mine rede darvmbe swie halt iv geschiht ### ich rat iv an den triwen welt ir ivch wol bewarn ### so svlt ir zvo den Hvnen vil gewærliche varn
###### 1505 | ### Sit ir niht welt erwinden so besendet iwer man ### die besten die ir vinden oder inder mvget han ### so wel ich voz in allen tvsent ritter gvot ### sone chan vns niht gewerren der argen Chriemh' mvot
###### 1506 | ### Des wil ich gerne volgen sprach der kunic zehant ### do hiez er boten riten witen in sin lant ### do brahte man der helde driv tvsint vn– mer ### si wanden niht erwerben also gremelichiv ser
###### 1507 | ### Si riten willechliche in Gunthers lant ### man hiez in gebn allen rosse vn– ovch gewant ### die mit in varn wolden zvo den Hvnen dan ### der kunic in gvtem willen der vil manigen gewan
###### 1508 | ### Do hiez von Tronege Hagene Danchwart den brvoder sin ### ir beider rechen sehzich bringen an den Rin ### die chomen ritterliche harnasch vn– gewant ### des brahten vil die degene in daz Gunthers lant
###### 1509 | ### Do chom der herre Volker ein kvene spileman ### hin ze hove nach eren mit drizzech siner man ### die heten soelch gewæte ez moeht ein kunic tragen ### daz er zen Hvnin wolde daz hiez er dem chvnige sagen
###### 1510 | ### Wer der Volker wære daz wil ich wizzen lan ### er was ein edel herre im was ovch vndertan ### vil der gvoten rechen in Burgonden lant ### dvrch daz er videln kunde was er der spileman genant
###### 1511 | ### Tvsent welt Hagene die hete er wol bechant ### vn– swaz in starchen stvermen hete gefrvemt ir hant ### vn– swaz si ie begiengen des het er vil gesehn ### in chvnde ovch anders niemen niwan frvemcheite iehn
| ### Die boten von den Hvnen vil sere da verdroz ### wande ir vorht zir herren div was harte groz ### si gerten tægeliche vrlovbes von dan ### des engunde niht Hagene daz was dvrch liste getan
###### 1513 | ### Er sprach zvo sime herren wir svln daz wol bewarn ### daz wir si iht lazen riten e daz wir selbe varn ### dar nach in tagen sibenen wider in ir lant ### treit vns iemen argen mvot daz wirt vns deste baz bechant
###### 1514 | ### Sone chan ovch sich vroe Chriemh' bereiten niht dar zvo ### daz vns durch ir ræte iemen schaden tvo ### hat aber si den willen ez mag ir leide ergan ### wande wir fveren hinnen manigen vz erwelten man
###### 1515 | ### Sætil vn– schilde vn– ander ir gewant ### daz si fveren solden in Ezelen lant ### daz was nv gar bereitet vil manigem chvenem man ### die Ezelen videlære hiez man do ze hove gan
###### 1516 | ### Do si die fvrsten sahen do sprach Gernot ### der chvnic wil nv lei[57v]sten daz Ezel vns enbot ### wir wellen chomen gerne z siner hochgezit ### vn– sehn vnser swester daz ir des ane zwivel sit
| ### Do sprach der kunic Gvnther ir svlt vns wizzen lan ### wenne si die hochgezit zen Hunen wellen han ### des antwrtem kvnige der bote Swæmmelin ### ze næhsten svenewenden so sol si sicherchen sin
###### 1518 | ### Der chvnich in erlovbte des was noch niht geschehn ### ob si gerne wolden Prvnh' sehn ### daz si fvr si solden mit sime willen gan ### daz vnderstvnt do Volker daz was ir liebe getan
###### 1519 | ### Ian ist so sprach Volker ein <edel> ritter gvot ### Prvnh' min frowe nv niht wol gemvvot ### bitet vnze morgen so læt mans ivch sehn ### do si sie wanden schowen done chvndes niht geschehen
###### 1520 | ### Do hiez der chvnic riche der was den boten holt ### dvrch sines hercen tvgende tragen dar sin golt ### vf den breiten schilden des er vil mohte han ### ovch wart in richiv gabe von sinen frivnden getan
###### 1521 | ### Gernot vn– Giselher Gere vn– oertwin ### daz ovch si milte wæren daz wart da vil wol schin ### also riche gabe si sie bvten an ### daz si ir vor ir herren deheine torsten enpfan
| ### Do sprach zvo dem chunige der bote Wærbelin ### her chvnic lat iwer gabe in ivrem lande sin ### wir mvgen ir niht gefvren min herre ez vns verbot ### daz wir iht gabe enpfiengen ovch ist es decheiner slahte not
###### 1523 | ### Des wart der chvnic here sere vngemvot ### daz si versprechen wolden so riches kvniges gvot ### doch mvsten si enpfahen sin golt vn– sin gewant ### daz si mit in brahten sit in Ezelen lant
###### 1524 | ### Si wolden sehen Vten ê daz si schieden dan ### Giselher der snelle braht die spileman ### ze hove fvr sine mvoter div frowe enbot do dan ### swaz si eren hete daz wære ir liebe getan
###### 1525 | ### Do hiez div kuniginne ir porten vn– ir golt ### gebn dvrch Chriemh' wan der was si holt ### vn– dvrch den kunec Ezelen den selben spileman ### si mohtenz wol enpfahen ez was mit triwen getan
| ### Vrlovp genomen heten von wibe vn– von man ### die boten Chriemh' mit frevden si do dan ### fvrn vnz in Swaben dar hiez si Gernot ### sine lvte leiten daz ez in niemen missebot
###### 1527 | ### Do sich die von in schieden die ir solden pflegn ### div Ezelen herschaft si vridet vof allen wegn ### des ennam in niemen ir ros noch ir gewant ### si begvnden vaste gahen wider in der Hvnen lant
###### 1528 | ### Swa si ir frivnde iht wisten daz taten i den chvnt ### daz die Burgonden in vil chvrcer stvnt ### zetal von Rine fveren in der Hvnen lant ### dem bisschofe Pilgerine div mære wrden ovch bechant
###### 1529 | ### Do si mit solher ile fvr Bechelaren riten ### si sagtenz Rvde[96r]ger des wart nicht vermiten ### vnd auch Gotlinde des margraffen weip ### daz si sew sehen solden des wart vil vroleichn– ir leip
###### 1530 | ### Gahen mit den maern sach man die poten dan ### Etzln si funden in der stat ze Gran ### dienst vbir dienst des man in vil enpot ### sagten si dem chünig vor liebe wart er freunden rot
###### 1531 | ### Do die chuniginne die maere recht enphant ### daz ir brüder solden chomen in das lant ### do was ir wol ze muote si gab den spilman ### also reiche gabe [96v]si mochtens immer frumen han
###### 1532 | ### Si sprach nu sagt rnir paide vil lieben poten mein ### welcher meiner frewnde hie pei vns welle sein ### der hochsten die wir ladaeten her in ditz lant ### si sprach was redet Hagen do er die maere bechant
###### 1533 | ### Er sprach er chome ze frage an ainem morgen fru ### nicht guotleicher sprache redt er do zu ### do si die raise lobten von Wurmtz vbir Reine ### daz wyzzet chüniginne ez chunde im laider nicht gesein
###### 1534 | ### Ez chomen ewr brüder die chünig al drey ### in herleichen mute wer rekchen mit im sei ### der maer ich endleiehe wizzen niman chan ### ez lobten mit im reiten Volker der chüne spilman
###### 1535 | ### Des enbaer ich leichte sprach des chunigs weip ### daz ich immer hie gesaehe den Volkers leip ### Hagen pin ich waege der ist ein rekche gut ### daz er chumpt zen Heunen des stat mir höch der mut
###### 1536 | ### Da gie die chüniginne da si den chünig sach ### wie rechte minicleichen frawe Chrimhild do sprach ### wie zaement ew die maer vil lieber herre ### des ie meine hertze gerte daz sol nu wol verendet [97r]sein
###### 1537 | ### Dein wille der ist mein freude sprach der chünig do ### ich enwart meine selbes mage nie so rechte vro ### so ich si weste chomende her in ditze lant ### durch liebe deiner frewnde ist meine sorge gar verswant
###### 1538 | ### Des chünigs amptleut die hiezzen vbir al ### mir gesidel richten palas vnd sal ### gen den lieben gesten die in da solden chomen ### seit wart von dem chunige vil michel wunne benomen

<<< Übersicht <<< vorige Seite nächste Seite >>>